@@ -29,6 +29,9 @@
 #include "goautils.h"
 #include "goawebview.h"
 #include "goaoauth2provider.h"
+#include "goaoauth2provider-priv.h"
+#include "goaoauth2provider-web-extension.h"
+
 
 /**
  * SECTION:goaoauth2provider
@@ -284,6 +287,8 @@ goa_oauth2_provider_build_authorization_uri (GoaOAuth2Provider  *provider,
                                                                                     escaped_scope);
 }
 
+/* ---------------------------------------------------------------------------------------------------- */
+
 /**
  * goa_oauth2_provider_process_redirect_url:
  * @provider: A #GoaOAuth2Provider.
@@ -765,10 +770,8 @@ get_tokens_sync (GoaOAuth2Provider  *provider,
   g_clear_error (&tokens_error);
   g_free (ret_access_token);
   g_free (ret_refresh_token);
-  if (call != NULL)
-    g_object_unref (call);
-  if (proxy != NULL)
-    g_object_unref (proxy);
+  g_clear_object (&call);
+  g_clear_object (&proxy);
   return ret;
 }
 
@@ -974,7 +977,8 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
 
  ignore_request:
   g_assert (response_id != GTK_RESPONSE_NONE);
-  gtk_dialog_response (priv->dialog, response_id);
+  if (response_id < 0)
+    gtk_dialog_response (priv->dialog, response_id);
   webkit_web_policy_decision_ignore (policy_decision);
   return TRUE;
 
@@ -1070,6 +1074,7 @@ get_tokens_and_identity (GoaOAuth2Provider  *provider,
                     provider);
 
   gtk_container_add (GTK_CONTAINER (grid), web_view);
+  gtk_window_set_default_size (GTK_WINDOW (dialog), -1, -1);
 
   gtk_widget_show_all (GTK_WIDGET (vbox));
   gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1602,8 +1607,7 @@ goa_oauth2_provider_get_access_token_sync (GoaOAuth2Provider  *provider,
   g_free (refresh_token);
   g_free (old_refresh_token);
   g_free (password);
-  if (credentials != NULL)
-    g_variant_unref (credentials);
+  g_clear_pointer (&credentials, (GDestroyNotify) g_variant_unref);
 
   g_mutex_unlock (lock);
 
