@@ -603,10 +603,8 @@ get_tokens_sync (GoaOAuthProvider  *provider,
   g_free (ret_access_token);
   g_free (ret_access_token_secret);
   g_free (ret_session_handle);
-  if (call != NULL)
-    g_object_unref (call);
-  if (proxy != NULL)
-    g_object_unref (proxy);
+  g_clear_object (&call);
+  g_clear_object (&proxy);
   return ret;
 }
 
@@ -903,6 +901,7 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
                     &data);
 
   gtk_container_add (GTK_CONTAINER (grid), web_view);
+  gtk_window_set_default_size (GTK_WINDOW (dialog), -1, -1);
 
   gtk_widget_show_all (GTK_WIDGET (vbox));
   gtk_dialog_run (GTK_DIALOG (dialog));
@@ -965,8 +964,7 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
   ret = TRUE;
 
  out:
-  if (call != NULL)
-    g_object_unref (call);
+  g_clear_object (&call);
 
   if (ret)
     {
@@ -1000,8 +998,7 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
   g_free (url);
 
   g_free (data.oauth_verifier);
-  if (data.loop != NULL)
-    g_main_loop_unref (data.loop);
+  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
   g_free (data.access_token);
   g_free (data.access_token_secret);
   g_free (escaped_request_token);
@@ -1010,8 +1007,7 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
   g_free (data.request_token_secret);
 
   g_strfreev (request_params);
-  if (proxy != NULL)
-    g_object_unref (proxy);
+  g_clear_object (&proxy);
   return ret;
 }
 
@@ -1179,8 +1175,7 @@ goa_oauth_provider_add_account (GoaProvider *_provider,
   g_free (access_token_secret);
   g_free (session_handle);
   g_free (data.account_object_path);
-  if (data.loop != NULL)
-    g_main_loop_unref (data.loop);
+  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
   return ret;
 }
 
@@ -1553,8 +1548,7 @@ goa_oauth_provider_get_access_token_sync (GoaOAuthProvider   *provider,
   g_free (access_token_secret_for_refresh);
   g_free (session_handle_for_refresh);
   g_free (password);
-  if (credentials != NULL)
-    g_variant_unref (credentials);
+  g_clear_pointer (&credentials, (GDestroyNotify) g_variant_unref);
 
   g_mutex_unlock (lock);
 
